decent\_bench
=============

.. toctree::
   :maxdepth: 2

   decent_bench.metrics
   decent_bench.utils


.. toctree::
   :maxdepth: 2

   decent_bench.agent
   decent_bench.benchmark
   decent_bench.benchmark_problem
   decent_bench.centralized_algorithms
   decent_bench.cost_functions
   decent_bench.datasets
   decent_bench.distributed_algorithms
   decent_bench.network
   decent_bench.schemes

.. automodule:: decent_bench
   :members:
   :show-inheritance:
   :undoc-members:
